@@ -262,9 +262,7 @@ folder selectors work."
     (vm-biff-delete-popup)
     
     (cond ((and vm-biff-folder-frame (vm-biff-x-p))
-           (select-frame vm-biff-folder-frame)
-           (focus-frame vm-biff-folder-frame)
-           (raise-frame vm-biff-folder-frame)
+	   (vm-select-frame-set-input-focus vm-biff-folder-frame)
            (run-hooks 'vm-biff-select-frame-hook)
            (select-window vm-biff-folder-window))
           (vm-biff-folder-window
@@ -424,7 +422,7 @@ AddToFunc SelectWindow
           
           ;; if in the minibuffer then seletc a different window
           (if (active-minibuffer-window)
-              (other-window))
+              (other-window 1))
         
           ;; generate a own window/frame showing the messages
           (if (vm-biff-x-p)
@@ -453,7 +451,8 @@ AddToFunc SelectWindow
                 (make-frame-visible mf)
                 (setq wf mf)
               
-                (if vm-biff-focus-popup (focus-frame mf)
+                (if vm-biff-focus-popup 
+		    (vm-select-frame-set-input-focus mf)
                   (select-frame sf)))
 
             ;; Terminal
