@@ -19,39 +19,6 @@
 
 ;;; Code:
 
-;; Taken from XEmacs as GNU Emacs is missing `replace-in-string' and defining
-;; it may cause clashes with other packages defining it differently, in fact
-;; we could also call the function `replace-regexp-in-string' as Roland
-;; Winkler pointed out.
-(defun vm-replace-in-string (str regexp newtext &optional literal)
-  "Replace all matches in STR for REGEXP with NEWTEXT string,
- and returns the new string.
-Optional LITERAL non-nil means do a literal replacement.
-Otherwise treat `\\' in NEWTEXT as special:
-  `\\&' in NEWTEXT means substitute original matched text.
-  `\\N' means substitute what matched the Nth `\\(...\\)'.
-       If Nth parens didn't match, substitute nothing.
-  `\\\\' means insert one `\\'.
-  `\\u' means upcase the next character.
-  `\\l' means downcase the next character.
-  `\\U' means begin upcasing all following characters.
-  `\\L' means begin downcasing all following characters.
-  `\\E' means terminate the effect of any `\\U' or `\\L'."
-  (if (> (length str) 50)
-      (let ((cfs case-fold-search))
-	(with-temp-buffer
-          (setq case-fold-search cfs)
-	  (insert str)
-	  (goto-char 1)
-	  (while (re-search-forward regexp nil t)
-	    (replace-match newtext t literal))
-	  (buffer-string)))
-    (let ((start 0) newstr)
-      (while (string-match regexp str start)
-        (setq newstr (replace-match newtext t literal str)
-              start (+ (match-end 0) (- (length newstr) (length str)))
-              str newstr))
-      str)))
 
 (defun vm-delete-non-matching-strings (regexp list &optional destructively)
   "Delete strings matching REGEXP from LIST.
@@ -84,6 +51,7 @@ and flexible."
   (let (list tem)
     (store-match-data nil)
     (while (and (not (eq matches 0))
+		(not (eq (match-end 0) (length string)))
 		(string-match regexp string (match-end 0)))
       (and (integerp matches) (setq matches (1- matches)))
       (if (not (consp matchn))
@@ -315,6 +283,15 @@ and flexible."
 	      blobarray)
     list ))
 
+(defun vm-mapvector (proc vec)
+  (let ((new-vec (make-vector (length vec) nil))
+	(i 0)
+	(n (length vec)))
+    (while (< i n)
+      (aset new-vec i (apply proc (aref vec i) nil))
+      (setq i (1+ i)))
+    new-vec))
+
 (defun vm-mapcar (function &rest lists)
   (let (arglist result)
     (while (car lists)
@@ -341,6 +318,128 @@ and flexible."
 	(setq prev p p (cdr p))))
     list ))
 
+(defun vm-find (list pred)
+  "Find the first element of LIST satisfying PRED and return the position"
+  (let ((n 0))
+    (while (and list (not (apply pred (car list) nil)))
+      (setq list (cdr list))
+      (setq n (1+ n)))
+    (if list n nil)))
+
+(fset 'vm-view-file-other-frame
+      (if (fboundp 'view-file-other-frame)
+	  'view-file-other-frame
+	'view-file-other-window))
+
+(fset 'vm-interactive-p
+      (if (fboundp 'interactive-p)	; Xemacs or Gnu Emacs under obsolescence
+	  'interactive-p
+	(lambda () (called-interactively-p 'any))))
+
+(fset 'vm-device-type
+      (cond (vm-xemacs-p 'device-type)
+	    (vm-fsfemacs-p 'vm-fsfemacs-device-type)))
+
+(defun vm-fsfemacs-device-type (&optional device)
+  "An FSF Emacs emulation for XEmacs `device-type' function.  Returns
+the type of the current screen device: one of 'x, 'gtk, 'w32, 'ns and
+'pc.  The optional argument DEVICE is ignored."
+  (if (eq window-system 'x)
+      (if (featurep 'gtk) 'gtk)
+    window-system))
+
+(defun vm-generate-new-unibyte-buffer (name)
+  (if vm-xemacs-p
+      (generate-new-buffer name)
+    (let* (;; (default-enable-multibyte-characters nil)
+	   ;; don't need this because of set-buffer-multibyte below
+	   (buffer (generate-new-buffer name)))
+      (when (fboundp 'set-buffer-multibyte)
+	(with-current-buffer buffer
+	  (set-buffer-multibyte nil)))
+      buffer)))
+
+(defun vm-generate-new-multibyte-buffer (name)
+  (if vm-xemacs-p
+      (generate-new-buffer name)
+    (let* (;; (default-enable-multibyte-characters t)
+	   ;; don't need this because of set-buffer-multibyte below
+	   (buffer (generate-new-buffer name)))
+      (if (fboundp 'set-buffer-multibyte)
+	  (with-current-buffer buffer
+	    (set-buffer-multibyte t))
+	;; This error checking only works on FSF
+	(with-current-buffer buffer 
+	  (unless enable-multibyte-characters
+	    (error "VM internal error #1922: buffer is not multibyte"))))
+      buffer)))
+
+(defun vm-make-local-hook (hook)
+  (if (fboundp 'make-local-hook)	; Emacs/XEmacs 21
+      (make-local-hook hook)
+    ;; ignore it if undefined because calls to add-hook will add them locally
+    ))
+
+(fset 'xemacs-abbreviate-file-name 'abbreviate-file-name)
+
+(defun vm-abbreviate-file-name (path)
+  (if vm-xemacs-p
+      (xemacs-abbreviate-file-name path t)
+    (abbreviate-file-name path)))
+
+(fset 'emacs-find-file-name-handler 'find-file-name-handler)
+(defun vm-find-file-name-handler (filename operation)
+  (if (fboundp 'find-file-name-handler)
+      (condition-case ()
+	  (emacs-find-file-name-handler filename operation)
+	(wrong-number-of-arguments
+	 (emacs-find-file-name-handler filename)))
+    nil))
+
+(fset 'emacs-focus-frame 'focus-frame)
+(defun vm-select-frame-set-input-focus (frame)
+  (if (fboundp 'select-frame-set-input-focus)
+      ;; defined in FSF Emacs 22.1
+      (select-frame-set-input-focus frame)
+    (select-frame frame)
+    (emacs-focus-frame frame)
+    (raise-frame frame)))
+
+(fset 'emacs-get-buffer-window 'get-buffer-window)
+(defun vm-get-buffer-window (buffer &optional which-frames which-devices)
+  (condition-case nil			; try XEmacs
+      (or (emacs-get-buffer-window buffer which-frames which-devices)
+	  (and vm-search-other-frames
+	       (emacs-get-buffer-window buffer t t)))
+    (wrong-number-of-arguments
+     (condition-case nil		; try recent Gnu Emacs
+	 (or (emacs-get-buffer-window buffer which-frames)
+	     (and vm-search-other-frames
+		  (emacs-get-buffer-window buffer t)))
+       (wrong-number-of-arguments	; baseline old Emacs
+	(emacs-get-buffer-window buffer))))))
+
+(defun vm-get-visible-buffer-window (buffer &optional 
+					    which-frames which-devices)
+  (condition-case nil
+      (or (emacs-get-buffer-window buffer which-frames which-devices)
+	  (and vm-search-other-frames
+	       (emacs-get-buffer-window buffer t which-devices)))
+    (wrong-number-of-arguments
+     (condition-case nil
+	 (or (emacs-get-buffer-window buffer which-frames)
+	     (and vm-search-other-frames
+		  (get-buffer-window buffer 'visible)))
+       (wrong-number-of-arguments
+	(emacs-get-buffer-window buffer))))))
+
+(defun vm-force-mode-line-update ()
+  "Force a mode line update in all frames."
+  (if (fboundp 'force-mode-line-update)
+      (force-mode-line-update t)
+    (with-current-buffer (other-buffer)
+      (set-buffer-modified-p (buffer-modified-p)))))
+
 (defun vm-delete-directory-file-names (list)
   (vm-delete 'file-directory-p list))
 
@@ -841,6 +940,20 @@ If HACK-ADDRESSES is t, then the strings are considered to be mail addresses,
       (t
        (fset 'vm-coding-system-name 'symbol-name)))
 
+(if (fboundp 'coding-system-name)
+    (defun vm-coding-system-name-no-eol (coding-system)
+      (coding-system-name
+       (coding-system-change-eol-conversion coding-system nil)))
+  (defun vm-coding-system-name-no-eol (coding-system)
+    (coding-system-change-eol-conversion coding-system nil)))
+
+(if (fboundp 'coding-system-name)
+    (defun vm-coding-system-name-no-eol (coding-system)
+      (coding-system-name
+       (coding-system-change-eol-conversion coding-system nil)))
+  (defun vm-coding-system-name-no-eol (coding-system)
+    (coding-system-change-eol-conversion coding-system nil)))
+
 (defun vm-get-file-line-ending-coding-system (file)
   (if (not (or vm-fsfemacs-mule-p vm-xemacs-mule-p vm-xemacs-file-coding-p))
       nil
@@ -880,26 +993,147 @@ If HACK-ADDRESSES is t, then the strings are considered to be mail addresses,
   (while (re-search-forward "[ \t\n]+" nil 0)
     (replace-match " " t t)))
 
-(defun vm-fill-paragraphs-containing-long-lines (len start end)
-  (let ((done nil)
-	(buffer-read-only nil)
-	(fill-column vm-paragraph-fill-column)
-	;; user doesn't want long lines, so set this to zero for them.
-	(filladapt-fill-column-forward-fuzz 0))
+(defvar vm-paragraph-prefix-regexp "^[ >]*"
+  "A regexp used by `vm-forward-paragraph' to match paragraph prefixes.")
+
+(defvar vm-empty-line-regexp "^[ \t>]*$"
+  "A regexp used by `vm-forward-paragraph' to match paragraph prefixes.")
+
+(defun vm-skip-empty-lines ()
+  "Move forward as long as current line matches `vm-empty-line-regexp'."
+  (while (and (not (eobp)) 
+	      (looking-at vm-empty-line-regexp))
+    (forward-line 1)))
+
+(defun vm-forward-paragraph ()
+  "Move forward to end of paragraph and do it also right for quoted text.
+As a side-effect set `fill-prefix' to the paragraphs prefix.
+Returns t if there was a line longer than `fill-column'."
+  (let ((long-line)
+	(line-no 1)
+	len-fill-prefix)
+    (forward-line 0)			; cover for bad fill-region fns
+    (setq fill-prefix nil)
+    (while (and 
+	    ;; stop at end of buffer
+	    (not (eobp)) 
+	    ;; empty lines break paragraphs
+	    (not (looking-at "^[ \t]*$"))
+	    ;; do we see a prefix
+	    (looking-at vm-paragraph-prefix-regexp)
+	    (let ((m (match-string 0))
+		  lenm)
+	      (or (and (null fill-prefix)
+		       ;; save prefix for next line
+		       (setq fill-prefix m len-fill-prefix (length m)))
+		  ;; is it still the same prefix?
+		  (string= fill-prefix m)
+		  ;; or is it just shorter by whitespace on the second line
+		  (and 
+		   (= line-no 2)
+		   (< (setq lenm (length m)) len-fill-prefix)
+		   (string-match "^[ \t]+$" (substring fill-prefix lenm))
+		   ;; then save new shorter prefix
+		   (setq fill-prefix m len-fill-prefix lenm)))))
+      (end-of-line)
+      (setq line-no (1+ line-no))
+      (setq long-line (or long-line (> (current-column) fill-column)))
+      (forward-line 1))
+    long-line))
+
+(defun vm-fill-paragraphs-containing-long-lines (width start end)
+  "Fill paragraphs spanning more than WIDTH columns in region
+START to END.  If WIDTH is 'window-width, the current width of
+the Emacs window is used.  If vm-word-wrap-paragraphs is set
+non-nil, then the longlines package is used to word-wrap long
+lines without removing any existing line breaks.
+
+In order to fill also quoted text you will need `filladapt.el' as the adaptive
+filling of GNU Emacs does not work correctly here!"
+  (if (and vm-word-wrap-paragraphs (locate-library "longlines"))
+      (vm-fill-paragraphs-by-longlines start end)
+    (if (eq width 'window-width)
+	(setq width (- (window-width (get-buffer-window (current-buffer))) 1)))
+    (save-excursion
+      (let ((buffer-read-only nil)
+	    (fill-column vm-paragraph-fill-column)
+	    (adaptive-fill-mode nil)
+	    (abbrev-mode nil)
+	    (fill-prefix nil)
+	    ;; (use-hard-newlines t)
+	    (filled 0)
+	    (message (if (car vm-message-pointer)
+			 (vm-su-subject (car vm-message-pointer))
+		       (buffer-name)))
+	    (needmsg (> (- end start) 12000)))
+      
+	(if needmsg
+	    (message "Filling message to column %d!" fill-column))
+      
+	;; we need a marker for the end since this position might change 
+	(or (markerp end) (setq end (vm-marker end)))
+	(goto-char start)
+      
+	(while (< (point) end)
+	  (setq start (point))
+	  (vm-skip-empty-lines)
+	  (when (and (< (point) end)	; if no newline at the end
+		     (vm-forward-paragraph))
+	    (fill-region start (point))
+	    (setq filled (1+ filled))))
+      
+	;; Turning off these messages because they go by too fast and
+	;; are not particularly enlightening.  USR, 2010-01-26
+	;; (if (= filled 0)
+	;;    (message "Nothing to fill!")
+	;;  (message "Filled %s paragraph%s!"
+	;;           (if (> filled 1) (format "%d" filled) "one")
+	;;           (if (> filled 1) "s" "")))
+	))))
+
+(defun vm-fill-paragraphs-by-longlines (start end)
+  "Uses longlines.el for filling the region."
+  ;; prepare for longlines.el in XEmacs
+  (require 'overlay)
+  (require 'longlines)
+  (defvar fill-nobreak-predicate nil)
+  (defvar undo-in-progress nil)
+  (defvar longlines-mode-hook nil)
+  (defvar longlines-mode-on-hook nil)
+  (defvar longlines-mode-off-hook nil)
+  (unless (functionp 'replace-regexp-in-string)
+    (defun replace-regexp-in-string (regexp rep string
+                                            &optional fixedcase literal)
+      (vm-replace-in-string string regexp rep literal)))
+  (unless (functionp 'line-end-position)
+    (defun line-end-position ()
+      (save-excursion (end-of-line) (point))))
+  (unless (functionp 'line-beginning-position)
+    (defun line-beginning-position (&optional n)
+      (save-excursion
+        (if n (forward-line n))
+        (beginning-of-line)
+        (point)))
+    (unless (functionp 'replace-regexp-in-string)
+      (defun replace-regexp-in-string (regexp rep string
+                                              &optional fixedcase literal)
+        (vm-replace-in-string string regexp rep literal))))
+  ;; now do the filling
+  (let ((buffer-read-only nil)
+        (fill-column 
+	 (if (numberp vm-fill-paragraphs-containing-long-lines)
+	     vm-fill-paragraphs-containing-long-lines
+	   (- (window-width (get-buffer-window (current-buffer))) 1)))
+	)
     (save-excursion
       (vm-save-restriction
-       (widen)
-       (or (markerp end) (setq end (vm-marker end)))
-       (goto-char start)
-       (while (and (not done) (re-search-forward "[ \t]*$" end t))
-         (replace-match "")
-	 (if (>= (current-column) len)
-	     ;; ignore errors
-	     (condition-case nil
-		 (fill-paragraph nil)
-	       (error nil)))
-	 (forward-line)
-	 (setq done (>= (point) end)))))))
+       ;; longlines-wrap-region contains a (forward-line -1) which is causing
+       ;; wrapping of headers which is wrong, so we restrict it here!
+       (narrow-to-region start end)
+       (longlines-decode-region start end) ; make linebreaks hard
+       (longlines-wrap-region start end)  ; wrap, adding soft linebreaks
+       (widen)))))
+
 
 (defun vm-make-message-id ()
   (let (hostname
@@ -980,6 +1214,11 @@ If HACK-ADDRESSES is t, then the strings are considered to be mail addresses,
 		     1)
 	(delete-region (- (point) 1) (- (point) 4))))))
 
+(defun vm-process-kill-without-query (process &optional flag)
+  (if (fboundp 'process-kill-without-query)
+      (process-kill-without-query process flag)
+    (set-process-query-on-exit-flag process flag)))
+
 (defun vm-process-sentinel-kill-buffer (process what-happened)
   (kill-buffer (process-buffer process)))
 
@@ -1014,6 +1253,101 @@ If MODES is nil the take the modes from the variable
 	   (setq vm-disable-modes-ignore (cons m vm-disable-modes-ignore)))
 	 nil)))))
 
+(defun vm-add-write-file-hook (vm-hook-fn)
+  "Add a function to the hook called during write-file.
+
+Emacs changed the name of write-file-hooks to write-file-functions as of 
+Emacs 22.1. This function is used to supress compiler warnings."
+  (if (boundp 'write-file-functions)
+      (add-hook 'write-file-functions vm-hook-fn)
+    (add-hook 'write-file-hooks vm-hook-fn)))
+
+(defun vm-add-find-file-hook (vm-hook-fn)
+  "Add a function to the hook called during find-file.
+
+Emacs changed the name of the hook find-file-hooks to find-file-hook in
+Emacs 22.1. This function used to supress compiler warnings."
+  (if (boundp 'find-file-hook)
+      (add-hook 'find-file-hook vm-hook-fn)
+    (add-hook 'find-file-hooks vm-hook-fn)))
+
+;; Taken from XEmacs as GNU Emacs is missing `replace-in-string' and defining
+;; it may cause clashes with other packages defining it differently, in fact
+;; we could also call the function `replace-regexp-in-string' as Roland
+;; Winkler pointed out.
+(defun vm-replace-in-string (str regexp newtext &optional literal)
+  "Replace all matches in STR for REGEXP with NEWTEXT string,
+ and returns the new string.
+Optional LITERAL non-nil means do a literal replacement.
+Otherwise treat `\\' in NEWTEXT as special:
+  `\\&' in NEWTEXT means substitute original matched text.
+  `\\N' means substitute what matched the Nth `\\(...\\)'.
+       If Nth parens didn't match, substitute nothing.
+  `\\\\' means insert one `\\'.
+  `\\u' means upcase the next character.
+  `\\l' means downcase the next character.
+  `\\U' means begin upcasing all following characters.
+  `\\L' means begin downcasing all following characters.
+  `\\E' means terminate the effect of any `\\U' or `\\L'."
+  (if (> (length str) 50)
+      (let ((cfs case-fold-search))
+	(with-temp-buffer
+          (setq case-fold-search cfs)
+	  (insert str)
+	  (goto-char 1)
+	  (while (re-search-forward regexp nil t)
+	    (replace-match newtext t literal))
+	  (buffer-string)))
+    (let ((start 0) newstr)
+      (while (string-match regexp str start)
+        (setq newstr (replace-match newtext t literal str)
+              start (+ (match-end 0) (- (length newstr) (length str)))
+              str newstr))
+      str)))
+
+;; For verification of the correct buffer protocol
+;; Possible values are 'folder, 'presentation, 'summary, 'process
+
+;; (defvar vm-buffer-types nil)    ; moved to vm-vars.el
+
+(defvar vm-buffer-type-debug nil
+  "*This flag can be set to t for debugging asynchronous buffer change
+  errors.")
+
+(defvar vm-buffer-type-debug nil)	; for debugging asynchronous
+					; buffer change errors
+(defvar vm-buffer-type-trail nil)
+
+(defun vm-buffer-type:enter (type)
+  (if vm-buffer-type-debug
+      (setq vm-buffer-type-trail 
+	    (cons type (cons 'enter vm-buffer-type-trail))))
+  (setq vm-buffer-types (cons type vm-buffer-types)))
+
+(defun vm-buffer-type:exit ()
+  (if vm-buffer-type-debug
+      (setq vm-buffer-type-trail (cons 'exit vm-buffer-type-trail)))
+  (setq vm-buffer-types (cdr vm-buffer-types)))
+
+(defun vm-buffer-type:duplicate ()
+  (if vm-buffer-type-debug
+      (setq vm-buffer-type-trail (cons (car vm-buffer-type-trail)
+				       vm-buffer-type-trail)))
+  (setq vm-buffer-types (cons (car vm-buffer-types) vm-buffer-types)))
+
+(defun vm-buffer-type:set (type)
+  (when vm-buffer-type-debug
+    (if (and (eq type 'folder) vm-buffer-types 
+	     (eq (car vm-buffer-types) 'process))
+	(debug "folder buffer being entered at inner level"))
+    (setq vm-buffer-type-trail (cons type vm-buffer-type-trail)))
+  (if vm-buffer-types
+      (rplaca vm-buffer-types type)
+    (setq vm-buffer-types (cons type vm-buffer-types))))
+
+(defsubst vm-buffer-type:assert (type)
+  (vm-assert (eq (car vm-buffer-types) type)))
+
 (provide 'vm-misc)
 
 ;;; vm-misc.el ends here
