@@ -7,7 +7,6 @@
 ;; Status:      Tested with XEmacs 21.4.15 & VM 7.19
 ;; Keywords:    sending mail, default mail, multiple recipients, serial mails
 ;; X-URL:       http://www.robf.de/Hacking/elisp
-;; Version:     $Id$
 
 ;;
 ;; This code is free software; you can redistribute it and/or modify
@@ -848,13 +847,13 @@ questions will bother you!"
           (run-hooks 'vm-mail-hook)
           (run-hooks 'vm-mail-mode-hook)
           (setq buffer-undo-list nil)
-          (make-local-hook 'kill-buffer-hook)
+          (vm-make-local-hook 'kill-buffer-hook)
           (add-hook 'kill-buffer-hook
                     '(lambda ()
                        (vm-serial-send-mail-increment 'vm-serial-killed-cnt))
                     t t)
           (add-hook 'kill-buffer-hook 'vm-serial-send-mail t t)
-          (make-local-hook 'mail-send-hook)
+          (vm-make-local-hook 'mail-send-hook)
           (add-hook 'mail-send-hook
                     '(lambda ()
                        (vm-serial-send-mail-increment 'vm-serial-sent-cnt))
