@@ -66,10 +66,11 @@ mandatory."
   (vm-check-for-killed-summary)
   (if (null vm-summary-buffer)
       (let ((b (current-buffer))
-	    (read-only vm-folder-read-only))
+	    (read-only vm-folder-read-only)
+	    (summary-buffer-name (format "%s Summary" (buffer-name))))
 	(setq vm-summary-buffer
-	      (let ((default-enable-multibyte-characters t))
-		(get-buffer-create (format "%s Summary" (buffer-name)))))
+	      (or (get-buffer summary-buffer-name)
+		  (vm-generate-new-multibyte-buffer summary-buffer-name)))
 	(save-excursion
 	  (set-buffer vm-summary-buffer)
 	  (abbrev-mode 0)
@@ -687,6 +688,7 @@ mandatory."
 		sexp-fmt nil)))
     (list last-match-end (if list (cons 'list list) sexp))))
 
+;;;###autoload
 (defun vm-get-header-contents (message header-name-regexp &optional clump-sep)
   (let ((contents nil)
 	regexp)
@@ -1221,6 +1223,7 @@ Argument msg is a message pointer."
 (defun vm-su-to-names (m)
   (or (vm-to-names-of m) (progn (vm-su-do-recipients m) (vm-to-names-of m))))
 				  
+;;;###autoload
 (defun vm-su-message-id (m)
   (or (vm-message-id-of m)
       (vm-set-message-id-of
@@ -1255,6 +1258,7 @@ Argument msg is a message pointer."
 	    (count-lines (vm-text-of (vm-real-message-of m))
 			 (vm-text-end-of (vm-real-message-of m)))))))))
 
+;;;###autoload
 (defun vm-su-subject (m)
   (or (vm-subject-of m)
       (vm-set-subject-of
